//---------------------------------------------------------------------------
#ifndef MidiPlayerH
#define MidiPlayerH
//---------------------------------------------------------------------------
#include <vcl\SysUtils.hpp>
#include <vcl\Controls.hpp>
#include <vcl\Classes.hpp>
#include <DsgnIntf.hpp>
#include <vcl\Forms.hpp>
#include <vcl\MPlayer.hpp>
//---------------------------------------------------------------------------
//  About box property
class TMidiAbout : public TPropertyEditor
{
public:
	__fastcall TMidiAbout();
	__fastcall ~TMidiAbout();
    virtual void __fastcall Edit(void);
	virtual TPropertyAttributes __fastcall GetAttributes(void);
	virtual System::AnsiString __fastcall GetValue(void);
};
/////////////////////////////////////////////////////////////////////////////
class TMidiFileName : public TPropertyEditor
{
protected:
	TPropertyAttributes __fastcall GetAttributes(void);
    void __fastcall Edit(void);
    virtual String __fastcall GetValue(void);
    virtual void __fastcall SetValue(String);
    virtual System::AnsiString __fastcall GetName();
public:
    __fastcall TMidiFileName();
	__fastcall virtual ~TMidiFileName();
};
/////////////////////////////////////////////////////////////////////////////
class TMidiPlayer : public TCustomControl
{
// friend class TMidiFileName;
// Return values for the MCI 'mode' command:
#define cmNotReady  0
#define cmPaused    1
#define cmPlaying   2
#define cmStopped   3
#define cmOpen      4
#define cmSeeking   5
#define cmParked    6
#define cmRecording 7

// Notifications from MM_MCINOTIFY
enum NotifyValues {nvSuccessful, nvSuperseded, nvAborted, nvFailure};

private:
    char RetMCI[256];
    int ErrVal;
    int Start;
    int FTempo;
    AnsiString FLengthMS;
    AnsiString FPositionMS;
	bool MidiOpen;
    NotifyValues FNotifyVal;
	TNotifyEvent FOnNotify;
    bool FNotify;
    TMidiFileName *FMidiFileName;
    String FSMidiFileName;
    TMidiAbout* FAbout;

	int __fastcall MCISend(AnsiString msg, char* ret, bool notify);
    void __fastcall Error(DWORD errnum);
	int __fastcall GetPosition();
    AnsiString __fastcall GetPositionMS();
	int __fastcall GetPort();
    int __fastcall GetTempo();
    void __fastcall SetTempo(int tempo);
    AnsiString __fastcall ConvertToMS(int value);
    int __fastcall GetLength();
    AnsiString __fastcall GetLengthMS();
	int __fastcall GetMidiMode();
    AnsiString __fastcall GetDivType();
    AnsiString __fastcall GetTimeForm();
    void __fastcall SetMidiFileName(String S);
    void __fastcall ReadHiddenFileName(TReader* Reader);
    void __fastcall WriteHiddenFileName(TWriter* Writer);
	void __fastcall Paint();

protected:
    virtual __fastcall ~TMidiPlayer();
    AnsiString GetShortName (AnsiString FileName);
    virtual void __fastcall DefineProperties(TFiler* Filer);
	MESSAGE void __fastcall MMNotify(TMessage &Message);
	MESSAGE void __fastcall WMSize(TWMSize &Message);
	BEGIN_MESSAGE_MAP
    	MESSAGE_HANDLER(MM_MCINOTIFY, TMessage, MMNotify);
    	MESSAGE_HANDLER(WM_SIZE, TWMSize, WMSize);
	END_MESSAGE_MAP(TCustomControl)

public:
	bool __fastcall Open(AnsiString AFileName);
    void __fastcall Close();
    AnsiString __fastcall SysInfo(AnsiString flag);
    void __fastcall Play();
	void __fastcall Stop();
    void __fastcall Resume();
    __property bool IsMidiOpen = {read=MidiOpen};
	__property int Position = {read=GetPosition};
    __property AnsiString PositionMS = {read=GetPositionMS};
    __property int Port = {read=GetPort};
    __property int Tempo = {read=FTempo, write=SetTempo};
    __property int Length = {read=GetLength};
    __property AnsiString LengthMS = {read=GetLengthMS};
    __property AnsiString DivisionType = {read=GetDivType};
    __property AnsiString TimeFormat = {read=GetTimeForm};
	__property int Mode = {read=GetMidiMode};
    __property String FileName = {read=FSMidiFileName, write=SetMidiFileName,
    	stored = true, nodefault };
    __property NotifyValues NotifyValue = {read=FNotifyVal};
    __fastcall TMidiPlayer(TComponent* Owner);

__published:
    __property Enabled;
    __property TMidiFileName* DummyFileName = {read=FMidiFileName, write=FMidiFileName,
    	stored=true, nodefault};
    __property TNotifyEvent OnNotify = {read=FOnNotify, write=FOnNotify};
	__property bool Notify = {read=FNotify, write=FNotify, default=false};
    __property TMidiAbout* About = {read=FAbout, write=FAbout};
       
};
//---------------------------------------------------------------------------
#endif
